@@ -8,7 +8,7 @@ try(gdal_metadata(tif, "wrongDomain"))
 gdal_metadata(tif, c("IMAGE_STRUCTURE"))
 try(length(gdal_metadata(tif, c("DERIVED_SUBDATASETS")))) # fails on Fedora 26
 
-if (require(stars) && utils::packageVersion("stars") >= "0.2-0") {
+if (require(stars, quietly = TRUE)) {
   tif = system.file("tif/geomatrix.tif", package = "sf")
   r = read_stars(tif)
   d = (st_dimensions(r))
@@ -41,6 +41,28 @@ if (require(stars) && utils::packageVersion("stars") >= "0.2-0") {
   print(p <- st_as_sf(x, as_points = FALSE)) # polygonize: follow raster boundaries
   print(p <- st_as_sf(x, as_points = FALSE, use_integer = TRUE)) # polygonize integers: follow raster boundaries
   print(try(p <- st_as_sf(x, as_points = TRUE))) # polygonize: contour, requies GDAL >= 2.4.0
+  if (utils::packageVersion("stars") >= "0.2-1") {
+    write_stars(read_stars(tif), tempfile(fileext = ".tif"))
+    write_stars(read_stars(tif, proxy = TRUE), tempfile(fileext = ".tif"))
+    write_stars(read_stars(tif, proxy = TRUE), tempfile(fileext = ".tif"), chunk_size = c(200,200))
+  	na.tif = read_stars(system.file("tif/na.tif", package = "stars"))
+  	write_stars(na.tif, "na.tif")
+  	write_stars(na.tif, "na.tif", NA_value = -999)
+  	na.tif = read_stars(system.file("tif/na.tif", package = "stars"), NA_value = -999)
+  	write_stars(na.tif, "na.tif")
+  	write_stars(na.tif, "na.tif", NA_value = -999)
+  	na.tif = read_stars(system.file("tif/na.tif", package = "stars"), NA_value = -999, proxy = TRUE)
+  	write_stars(na.tif, "na.tif")
+  	write_stars(na.tif, "na.tif", NA_value = -999)
+  }
+  # https://github.com/mtennekes/tmap/issues/368
+  if (utils::packageVersion("stars") > "0.4-0") {
+    lc = system.file('tif/lc.tif', package = 'stars')
+    if (lc != "") {
+	    r = read_stars(lc, RAT = "Land Cover Class")
+	    r <- droplevels(r)
+    }
+  }
 }
 
 r = gdal_read(tif)
@@ -49,13 +71,7 @@ gdal_inv_geotransform(gt)
 rc = expand.grid(x=1:3, y = 1:3)
 #(xy = xy_from_colrow(rc, gt))
 #xy_from_colrow(xy, gt, inverse = TRUE)
-gdal_crs(tif)
+crs <- gdal_crs(tif)
 
 try(gdal_metadata("foo"))
 gdal_metadata(tif)
-
-m = matrix(runif(100*100), 100, 100)
-m[ m > .8 ] = NA
-st = structure(list(m), dimensions = list(x = list(geotransform = c(0, 1.0, 0, 0, 0, 1.0))))
-gdal_write(st, file = tempfile(), driver = "GTiff", NA_value = -1.0, geotransform = c(0, 1.0, 0, 0, 0, 1.0))
-r = gdal_read(tif, NA_value = 255.0)
